@@ -44,7 +44,7 @@ ClassAssociationsPage::ClassAssociationsPage(QWidget *parent, UMLScene *s, UMLOb
 
     QHBoxLayout * layout = new QHBoxLayout(m_pAssocGB);
     layout->setSpacing(10);
-    layout->setMargin(margin);
+    layout->setContentsMargins(margin, margin, margin, margin);
 
     m_pAssocLW = new QListWidget(m_pAssocGB);
     m_pAssocLW->setContextMenuPolicy(Qt::CustomContextMenu);
@@ -94,7 +94,7 @@ void ClassAssociationsPage::fillListBox()
     m_pAssocLW->clear();
     m_pScene->getWidgetAssocs(m_pObject, m_List);
     int i = 0;
-    foreach(AssociationWidget* assocwidget, m_List) {
+    for(AssociationWidget *assocwidget : m_List) {
         if(assocwidget->associationType() != Uml::AssociationType::Anchor) {
             m_pAssocLW->insertItem(i, assocwidget->toString());
             i++;
